@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
-
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models
-
 from meta import settings as meta_settings
+from meta import utils
 from meta.models import ModelMeta
 from wagtail.core.models import Site
 from wagtail.images import get_image_model_string
@@ -84,7 +82,7 @@ class MetadataMixin(ModelMeta):
         return self.schemaorg_type or meta_settings.SCHEMAORG_TYPE
 
     def get_meta_site_name(self):
-        request = self.get_request()
+        request = utils.get_request()
         site = getattr(request, "site", None)
         if request and isinstance(site, Site):
             if bool(request.site.site_name) is True:
@@ -120,7 +118,7 @@ class MetadataMixin(ModelMeta):
         return self.custom_namespace or meta_settings.OG_NAMESPACES
 
     def get_domain(self):
-        request = self.get_request()
+        request = utils.get_request()
         if request and getattr(request, "site", None):
             return request.site.hostname
 
@@ -135,7 +133,7 @@ class MetadataMixin(ModelMeta):
         return meta_settings.SITE_DOMAIN
 
     def get_author(self):
-        class Author(object):
+        class Author:
             fb_url = meta_settings.FB_AUTHOR_URL
             twitter_profile = meta_settings.TWITTER_AUTHOR
             schemaorg_profile = None
@@ -146,7 +144,7 @@ class MetadataMixin(ModelMeta):
         return Author()
 
     def build_absolute_uri(self, url):
-        request = self.get_request()
+        request = utils.get_request()
         if request is not None:
             return request.build_absolute_uri(url)
 
@@ -155,12 +153,12 @@ class MetadataMixin(ModelMeta):
 
         site = self.get_site()
         if site is not None:
-            return "%s%s" % (site.root_url, url if url.startswith("/") else "/" + url)
+            return "{}{}".format(site.root_url, url if url.startswith("/") else "/" + url)
 
         raise NotImplementedError
 
     def get_context(self, request):
-        context = super(MetadataMixin, self).get_context(request)
+        context = super().get_context(request)
         context[self.context_meta_name] = self.as_meta(request)
         return context
 
@@ -203,10 +201,10 @@ class MetadataPageMixin(MetadataMixin, models.Model):
             return self.build_absolute_uri(
                 self.search_image.get_rendition(getattr(settings, "META_SEARCH_IMAGE_RENDITION", "fill-800x450")).url
             )
-        return super(MetadataPageMixin, self).get_meta_image()
+        return super().get_meta_image()
 
     def get_author(self):
-        author = super(MetadataPageMixin, self).get_author()
+        author = super().get_author()
         if hasattr(self, "owner") and isinstance(self.owner, get_user_model()):
             author.get_full_name = self.owner.get_full_name
         return author
